@@ -9,7 +9,7 @@
 
 #define lba28_limit ((__u64)(1<<28) - 1)
 
-void identify (__u16 *id_supplied);
+void identify (int fd, __u16 *id_supplied);
 void usage_error(int out) __attribute__((noreturn));
 void no_scsi (void);
 void no_xt (void);
@@ -30,6 +30,8 @@ int  wdidle3_get_timeout (int fd, unsigned char *timeout);
 void wdidle3_print_timeout (unsigned char timeout);
 unsigned char wdidle3_msecs_to_timeout (unsigned int msecs);
 
+int get_id_log_page_data (int fd, __u8 pagenr, __u8 *buf);
+
 extern const char *BuffType[4];
 
 struct local_hd_big_geometry {
@@ -93,3 +95,59 @@ enum {	/* ioctl() numbers */
 #endif
 #define BLKGETSIZE64 _IOR(0x12,114,__u64)
 
+
+/*
+ * Sanitize Device FEATURE field values
+ */
+enum {
+	SANITIZE_STATUS_EXT 			= 0x0000,
+	SANITIZE_CRYPTO_SCRAMBLE_EXT 	= 0x0011,
+	SANITIZE_BLOCK_ERASE_EXT		= 0x0012,
+	SANITIZE_OVERWRITE_EXT			= 0x0014,
+	SANITIZE_FREEZE_LOCK_EXT		= 0x0020,
+	SANITIZE_ANTIFREEZE_LOCK_EXT	= 0x0040,
+};
+
+/*
+ * Sanitize commands keys
+ */
+enum {
+	SANITIZE_FREEZE_LOCK_KEY		= 0x46724C6B,	/* "FrLk" */
+	SANITIZE_ANTIFREEZE_LOCK_KEY	= 0x416E7469,	/* "Anti" */
+	SANITIZE_CRYPTO_SCRAMBLR_KEY	= 0x43727970,	/* "Cryp" */
+	SANITIZE_BLOCK_ERASE_KEY		= 0x426B4572,	/* "BkEr" */
+	SANITIZE_OVERWRITE_KEY			= 0x00004F57,	/* "OW"   */
+};
+
+/*
+ * Sanitize states
+ */
+enum {
+	SANITIZE_IDLE_STATE_SD0,
+	SANITIZE_FROZEN_STATE_SD1,
+	SANITIZE_OPERATION_IN_PROGRESS_SD2,
+	SANITIZE_OPERATION_FAILED_SD3,
+	SANITIZE_OPERATION_SUCCEEDED_SD4,
+	SANITIZE_STATE_NUMBER
+};
+
+/*
+ * Sanitize outputs flags
+ */
+enum {
+	SANITIZE_FLAG_OPERATION_SUCCEEDED	= (1 << 7),
+	SANITIZE_FLAG_OPERATION_IN_PROGRESS	= (1 << 6),
+	SANITIZE_FLAG_DEVICE_IN_FROZEN		= (1 << 5),
+	SANITIZE_FLAG_ANTIFREEZE_BIT		= (1 << 4),
+};
+/*
+ * Sanitize devise error reason
+ */
+enum {
+	SANITIZE_ERR_NO_REASON,
+	SANITIZE_ERR_CMD_UNSUCCESSFUL,
+	SANITIZE_ERR_CMD_UNSUPPORTED,
+	SANITIZE_ERR_DEVICE_IN_FROZEN,
+	SANITIZE_ERR_ANTIFREEZE_LOCK,
+	SANITIZE_ERR_NUMBER
+};
